@@ -4,24 +4,18 @@ Main entrypoint for builder.
 import sys
 from collections.abc import Iterable
 
-from boto3 import __version__ as boto3_version
 from boto3.session import Session
-from botocore import __version__ as botocore_version
 
 from mypy_boto3_builder.aiobotocore_generator import AioBotocoreGenerator
 from mypy_boto3_builder.boto3_generator import Boto3Generator
 from mypy_boto3_builder.cli_parser import parse_args
-from mypy_boto3_builder.constants import BOTO3_STUBS_NAME, DUMMY_REGION, MODULE_NAME, PYPI_NAME
+from mypy_boto3_builder.constants import DUMMY_REGION, Product
 from mypy_boto3_builder.jinja_manager import JinjaManager
 from mypy_boto3_builder.logger import get_logger
 from mypy_boto3_builder.service_name import ServiceName, ServiceNameCatalog
-from mypy_boto3_builder.utils.boto3_changelog import Boto3Changelog
-from mypy_boto3_builder.utils.strings import (
-    get_aiobotocore_version,
-    get_anchor_link,
-    get_botocore_class_name,
-    get_min_build_version,
-)
+from mypy_boto3_builder.utils.botocore_changelog import BotocoreChangelog
+from mypy_boto3_builder.utils.strings import get_anchor_link, get_botocore_class_name
+from mypy_boto3_builder.utils.version import get_botocore_version
 
 
 def get_selected_service_names(
@@ -45,17 +39,18 @@ def get_selected_service_names(
     available_map = {i.name: i for i in available}
     result: list[ServiceName] = []
     selected_service_names = list(selected)
+    botocore_version = get_botocore_version()
     if ServiceName.ALL in selected_service_names:
         return list(available)
     if ServiceName.UPDATED in selected_service_names:
         selected_service_names.remove(ServiceName.UPDATED)
-        for updated_service_name in Boto3Changelog().get_updated_service_names(boto3_version):
+        for updated_service_name in BotocoreChangelog().get_updated_service_names(botocore_version):
             if updated_service_name in available_map:
                 selected_service_names.append(updated_service_name)
 
     for service_name_str in selected_service_names:
         if service_name_str not in available_map:
-            logger.info(f"Service {service_name_str} is not provided by boto3, skipping")
+            logger.info(f"Service {service_name_str} is not provided by botocore, skipping")
             continue
         result.append(available_map[service_name_str])
 
@@ -108,15 +103,7 @@ def main() -> None:
 
     service_names = get_selected_service_names(args.service_names, available_service_names)
 
-    aiobotocore_version = get_aiobotocore_version()
     JinjaManager.update_globals(
-        master_pypi_name=PYPI_NAME,
-        master_module_name=MODULE_NAME,
-        boto3_stubs_name=BOTO3_STUBS_NAME,
-        boto3_version=boto3_version,
-        botocore_version=botocore_version,
-        build_version=boto3_version,
-        min_build_version=get_min_build_version(boto3_version),
         builder_version=args.builder_version,
         get_anchor_link=get_anchor_link,
         render_docstrings=True,
@@ -132,7 +119,7 @@ def main() -> None:
         generate_setup=not args.installed,
         skip_published=args.skip_published,
         disable_smart_version=args.disable_smart_version,
-        version=args.build_version or boto3_version,
+        version=args.build_version,
     )
     aiobotocore_generator = AioBotocoreGenerator(
         service_names=service_names,
@@ -143,20 +130,19 @@ def main() -> None:
         generate_setup=not args.installed,
         skip_published=args.skip_published,
         disable_smart_version=args.disable_smart_version,
-        version=args.build_version or aiobotocore_version,
+        version=args.build_version,
     )
-    if "boto3" in args.products:
-        boto3_generator.generate_stubs()
-    if "boto3-services" in args.products:
-        boto3_generator.generate_service_stubs()
-    if "boto3-docs" in args.products:
-        boto3_generator.generate_docs()
-    if "aiobotocore" in args.products:
-        aiobotocore_generator.generate_stubs()
-    if "aiobotocore-services" in args.products:
-        aiobotocore_generator.generate_service_stubs()
-    if "aiobotocore-docs" in args.products:
-        aiobotocore_generator.generate_docs()
+    generators_map = {
+        Product.boto3: boto3_generator.generate_stubs,
+        Product.boto3_services: boto3_generator.generate_service_stubs,
+        Product.boto3_docs: boto3_generator.generate_docs,
+        Product.aiobotocore: aiobotocore_generator.generate_stubs,
+        Product.aiobotocore_services: aiobotocore_generator.generate_service_stubs,
+        Product.aiobotocore_docs: aiobotocore_generator.generate_docs,
+    }
+    generators = [generators_map[p] for p in args.products]
+    for generator in generators:
+        generator()
 
     logger.info("Completed")
 
