@@ -2,12 +2,14 @@
 Parser that produces `structures.Boto3StubsPackage`.
 """
 from collections.abc import Iterable
+from typing import Type as _Type
 
 from boto3.session import Session
 from botocore.config import Config
 
 from mypy_boto3_builder.enums.service_module_name import ServiceModuleName
 from mypy_boto3_builder.import_helpers.import_string import ImportString
+from mypy_boto3_builder.package_data import BasePackageData, Boto3StubsPackageData
 from mypy_boto3_builder.parsers.fake_service_package import parse_fake_service_package
 from mypy_boto3_builder.service_name import ServiceName
 from mypy_boto3_builder.structures.argument import Argument
@@ -23,7 +25,7 @@ from mypy_boto3_builder.type_annotations.type_subscript import TypeSubscript
 
 
 def parse_boto3_stubs_package(
-    session: Session, service_names: Iterable[ServiceName]
+    session: Session, service_names: Iterable[ServiceName], package_data: _Type[BasePackageData]
 ) -> Boto3StubsPackage:
     """
     Parse data for boto3_stubs package.
@@ -35,9 +37,11 @@ def parse_boto3_stubs_package(
     Returns:
         Boto3StubsPackage structure.
     """
-    result = Boto3StubsPackage(service_names=service_names)
+    result = Boto3StubsPackage(package_data, service_names=service_names)
     for service_name in result.service_names:
-        result.service_packages.append(parse_fake_service_package(session, service_name))
+        result.service_packages.append(
+            parse_fake_service_package(session, service_name, package_data)
+        )
 
     init_arguments = [
         Argument("region_name", TypeSubscript(Type.Optional, [Type.str]), Type.Ellipsis),
@@ -59,6 +63,7 @@ def parse_boto3_stubs_package(
     if len(result.service_packages) > 1:
         client_function_decorators.append(Type.overload)
     for service_package in result.service_packages:
+        package_name = Boto3StubsPackageData.get_service_package_name(service_package.service_name)
         service_argument = Argument(
             "service_name",
             TypeLiteral(
@@ -75,9 +80,7 @@ def parse_boto3_stubs_package(
                 *init_arguments,
             ],
             return_type=ExternalImport(
-                source=ImportString(
-                    service_package.service_name.module_name, ServiceModuleName.client.value
-                ),
+                source=ImportString(package_name, ServiceModuleName.client.value),
                 name=service_package.client.name,
             ),
             body_lines=["..."],
@@ -94,9 +97,7 @@ def parse_boto3_stubs_package(
                     *init_arguments,
                 ],
                 return_type=ExternalImport(
-                    source=ImportString(
-                        service_package.service_name.module_name, ServiceModuleName.client.value
-                    ),
+                    source=ImportString(package_name, ServiceModuleName.client.value),
                     name=service_package.client.name,
                 ),
                 body_lines=["..."],
@@ -109,6 +110,7 @@ def parse_boto3_stubs_package(
         resource_function_decorators.append(Type.overload)
     for service_package in service_resource_packages:
         assert service_package.service_resource
+        package_name = Boto3StubsPackageData.get_service_package_name(service_package.service_name)
         service_argument = Argument(
             "service_name",
             TypeLiteral(
@@ -125,10 +127,7 @@ def parse_boto3_stubs_package(
                 *init_arguments,
             ],
             return_type=ExternalImport(
-                source=ImportString(
-                    service_package.service_name.module_name,
-                    ServiceModuleName.service_resource.value,
-                ),
+                source=ImportString(package_name, ServiceModuleName.service_resource.value),
                 name=service_package.service_resource.name,
             ),
             body_lines=["..."],
@@ -145,10 +144,7 @@ def parse_boto3_stubs_package(
                     *init_arguments,
                 ],
                 return_type=ExternalImport(
-                    source=ImportString(
-                        service_package.service_name.module_name,
-                        ServiceModuleName.service_resource.value,
-                    ),
+                    source=ImportString(package_name, ServiceModuleName.service_resource.value),
                     name=service_package.service_resource.name,
                 ),
                 body_lines=["..."],
