@@ -3,12 +3,6 @@ Description for boto3 service.
 """
 from typing import Literal
 
-from mypy_boto3_builder.constants import (
-    AIOBOTOCORE_MODULE_NAME,
-    AIOBOTOCORE_PYPI_NAME,
-    MODULE_NAME,
-    PYPI_NAME,
-)
 from mypy_boto3_builder.utils.strings import get_anchor_link, is_reserved
 
 __all__ = (
@@ -80,34 +74,6 @@ class ServiceName:
 
         return name
 
-    @property
-    def module_name(self) -> str:
-        """
-        Package name for given service for boto3.
-        """
-        return f"{MODULE_NAME}_{self.underscore_name}"
-
-    @property
-    def aiobotocore_module_name(self) -> str:
-        """
-        Package name for given service for aiobotocore.
-        """
-        return f"{AIOBOTOCORE_MODULE_NAME}_{self.underscore_name}"
-
-    @property
-    def pypi_name(self) -> str:
-        """
-        Name of boto3 package on PyPI.
-        """
-        return f"{PYPI_NAME}-{self.name}"
-
-    @property
-    def aiobotocore_pypi_name(self) -> str:
-        """
-        Name of aiobotocore package on PyPI.
-        """
-        return f"{AIOBOTOCORE_PYPI_NAME}-{self.name}"
-
     @property
     def extras_name(self) -> str:
         """
